using UnityEngine;
using System.Collections;
using System.Collections.Generic; 

/// <summary>
/// renders the game menu; acts as an extension to the GameController but separated out to make the code/project more 
/// legible (as opposed to bundling it up in one source file) 
/// </summary>
[RequireComponent (typeof (LeaderboardController))]
public class GameMenuController : MonoBehaviour {
	
	/// <summary>
	/// OnGUI is a MonoBehaviour hook method - this provides an easy way to implement a 2D menu system NB; 
	/// for mobile it is recommend that you use alternative method as OnGUI is fairly heavy. For in game menus (HUD - Heads 
	/// Up Display) you should use a texture atlas (aka sprite sheet) to reduce draw calls and render them onto geometry and for 
	/// menus (less processor intensive scenes) we can either use GUITextures or OnGUI. 
	/// </summary>
	void OnGUI () {
		
		if( _showInstructions ){
			// draw instructions 
			GUI.DrawTexture( new Rect( 67 * _scaleOffset.x, 80 * _scaleOffset.y, 510 * _scale, 309 * _scale ), instructionsTex );							
			
		} else{
			// draw title 
			GUI.DrawTexture( new Rect( 67 * _scaleOffset.x, 188 * _scaleOffset.y, 447 * _scale, 113 * _scale ), titleTex );							
		}
			
			// leaderboard background  leaderboardBgTex
			GUI.BeginGroup( new Rect( Screen.width - (214 + 10) * _scale, (Screen.height - (603 * _scale)) / 2, 215 * _scale, 603 * _scale ) ); 
			
			GUI.DrawTexture( new Rect( 0, 0, 215 * _scale, 603 * _scale ), leaderboardBgTex );
			
			// size of leaderboard 
			Rect leaderboardTable = new Rect( 17 * _scaleOffset.x, 50 * _scaleOffset.y, 180 * _scale, 534 * _scale ); 
			if( _leaderboardController.IsFacebookAvailable && !_leaderboardController.IsLoggedIn ){
				// take into account the size of the button	
				leaderboardTable = new Rect( 17 * _scaleOffset.x, 50 * _scaleOffset.y, 180 * _scale, 410 * _scale ); 
				
				// draw copy
				GUI.DrawTexture( new Rect( 29* _scaleOffset.x, 477* _scaleOffset.y, 156 * _scale, 42 * _scale ), loginCopyTex );
				
				// draw facebook button 
				if (GUI.Button( new Rect ( 41 * _scaleOffset.x, 529 * _scaleOffset.y, 135 * _scale, 50 * _scale ), fbButtonTex, GUIStyle.none) )
				{
					_leaderboardController.LoginToFacebook(); 
				}			
			} 
			
			GUI.BeginGroup( leaderboardTable ); 
			
			if( _scores != null ){
				for( int i=0; i<_scores.Count; i++ ){
					Rect nameRect = new Rect( 5 * _scaleOffset.x, (20 * _scaleOffset.y) + i * 35 * _scale, 109 * _scale, 35 * _scale ); 
					Rect scoreRect = new Rect( 139 * _scaleOffset.x, (20 * _scaleOffset.y) + i * 35 * _scale, 52 * _scale, 35 * _scale ); 
					
					GUI.Label( nameRect, _scores[i].name ); 
					GUI.Label( scoreRect, _scores[i].points.ToString() ); 
				}
			}
						
			GUI.EndGroup(); 
	
			GUI.EndGroup();
			
		}
		
	}
}
